@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "humanoid-themes" "0.4"
+(define-package "humanoid-themes" "20251106.1956"
   "Color themes with a dark and light variant."
   '((emacs "27.1"))
   :url "https://github.com/humanoid-colors/emacs-humanoid-themes"
-  :commit "7dd4fe1211e0af187ae9ad4db6d5bea9e3e944f9"
-  :revdesc "0.4-0-g7dd4fe1211e0"
+  :commit "4adf696a5d9968f6328f488a1f606558cfc8f940"
+  :revdesc "4adf696a5d99"
   :keywords '("faces" "color" "theme"))
